@@ -6,6 +6,7 @@ import requests
 from airflow.operators.python import PythonOperator
 from datetime import datetime
 import json
+import awswrangler as wr
 
 DIEGO_MAX_ROWS = 10000000
 log = logging.getLogger(__name__)
@@ -74,7 +75,11 @@ class DiegoOperator(PythonOperator):
     def __upload_df_to_s3_temp(self, df: pd.DataFrame, path, part_number, pandas_kwargs=None):
         if pandas_kwargs is None:
             pandas_kwargs = dict()
-        df.to_parquet(path=f"{path}/{part_number}.parquet")
+        # df.to_parquet(path=f"{path}/{part_number}.parquet")
+        wr.s3.to_parquet(
+            dataframe=df,
+            path=f"{path}/{part_number}.parquet"
+)
 
         return True
 
